@@ -1,8 +1,8 @@
 from flask import current_app
-from jsonclasses.jsonclass_object import JSONClassObject
+from jsonclasses.jobject import JObject
 from jwt import encode
 
 
-def encode_jwt_token(operator: JSONClassObject) -> str:
+def encode_jwt_token(operator: JObject) -> str:
     key = current_app.config['jsonclasses_encode_key']
     return encode({'operator': operator._id}, key, algorithm='HS256')
